@@ -7,7 +7,7 @@ from functools import cmp_to_key
 
 import requests
 from requests.exceptions import HTTPError
-
+from requests.auth import _basic_auth_str
 from dkutils.constants import (
     API_DELETE,
     API_GET,
@@ -32,6 +32,7 @@ from dkutils.dictionary_comparator import DictionaryComparator
 from dkutils.validation import get_max_concurrency, skip_token_validation
 from dkutils.wait_loop import WaitLoop
 from .datetime_utils import get_utc_timestamp
+from .kitchen import Kitchen
 
 logger = logging.getLogger(__name__)
 
@@ -104,7 +105,14 @@ def ensure_and_get_kitchen(kitchen, kitchens):
 class DataKitchenClient:
 
     def __init__(
-        self, username, password, base_url=None, kitchen=None, recipe=None, variation=None
+        self,
+        username,
+        password,
+        base_url=None,
+        kitchen=None,
+        recipe=None,
+        variation=None,
+        is_api_token=False
     ):
         """
         Client object for invoking DataKitchen API calls. If the API call requires a kitchen,
@@ -126,12 +134,15 @@ class DataKitchenClient:
             Recipe to use in API requests
         variation : str, optional
             Variation to use in API requests
+        is_api_token: bool, optional
+            Indicates whether username and possword are an api token pair
         """
         self._username = username
         self._password = password
         self._base_url = base_url if base_url else DEFAULT_DATAKITCHEN_URL
         self._token = None
         self._headers = None
+        self._is_api_token = is_api_token
         self._refresh_token()
         self.kitchen = kitchen
         self.recipe = recipe
@@ -250,9 +261,15 @@ class DataKitchenClient:
         api_request = getattr(requests, http_method)
         api_path = f'{self._base_url}/v2/{"/".join(args)}'
         if is_json:
-            response = api_request(api_path, headers=self._headers, json=kwargs)
+            if len(kwargs) == 1 and 'json' in kwargs:
+                response = api_request(api_path, headers=self._headers, json=kwargs['json'])
+            else:
+                response = api_request(api_path, headers=self._headers, json=kwargs)
         else:
-            response = api_request(api_path, headers=self._headers, data=kwargs)
+            if len(kwargs) == 1 and 'data' in kwargs:
+                response = api_request(api_path, headers=self._headers, data=kwargs['data'])
+            else:
+                response = api_request(api_path, headers=self._headers, data=kwargs)
 
         try:
             response.raise_for_status()
@@ -272,6 +289,8 @@ class DataKitchenClient:
         boolean
             True if the current token is valid, False otherwise
         """
+        if self._is_api_token:
+            return True
         try:
             self._api_request(API_GET, 'validatetoken')
             return True
@@ -289,6 +308,9 @@ class DataKitchenClient:
         HTTPError
             If the login request fails to obtain a new token (e.g. login credentials are invalid).
         """
+        if self._is_api_token:
+            self._set_headers()
+
         if self._validate_token():
             return
 
@@ -299,9 +321,38 @@ class DataKitchenClient:
 
     def _set_headers(self):
         """
-        Set the headers dictionary with the current token.
+        Set the headers dictionary with the current token or api_token
         """
-        self._headers = {'Authorization': f'Bearer {self._token}'}
+        if self._is_api_token:
+            self._headers = {'Authorization': _basic_auth_str(self._username, self._password)}
+        else:
+            self._headers = {'Authorization': f'Bearer {self._token}'}
+
+    def get_kitchen(self):
+        """
+        Create and return a kitchen object for use in making kitchen related API requests.
+        """
+        self._ensure_attributes(KITCHEN)
+        return Kitchen(self, self.kitchen)
+
+    def create_kitchen(self, name: str, description: str = ''):
+        """
+        Create a child kitchen off of self.kitchen and return a Kitchen object for the newly
+        created kitchen.
+
+        Parameters
+        ----------
+        name : str
+            New kitchen name
+        description : str
+            New kitchen description
+
+        Returns
+        -------
+        Kitchen
+        """
+        self._ensure_attributes(KITCHEN)
+        return Kitchen.create(self, self.kitchen, name, description)
 
     def create_order(self, parameters={}):
         """
@@ -645,7 +696,15 @@ class DataKitchenClient:
                 f'No order runs found for provided order id ({order_id}) in kitchen {self.kitchen}'
             )
 
-    def get_order_run_details(self, order_run_id):
+    def get_order_run_details(
+        self,
+        order_run_id,
+        include_logs=False,
+        include_servingjson=False,
+        include_summary=False,
+        include_testresults=False,
+        include_timingresults=False
+    ):
         """
         Retrieve the details of an order run.
 
@@ -653,6 +712,16 @@ class DataKitchenClient:
         ----------
         order_run_id : str
             Order run id for which to retrieve details
+        include_logs : boolean
+             Include logs in response (Default: False)
+        include_servingjson : boolean
+            Include servings in response (Default: False)
+        include_summary : boolean
+            Include summary information in response (Default: False)
+        include_testresults : boolean
+            Include test results in response (Default: False)
+        include_timingresults : boolean
+            Include timing results in response (Default: False)
 
         Raises
         ------
@@ -705,12 +774,12 @@ class DataKitchenClient:
             'order',
             'details',
             self.kitchen,
-            logs=False,
+            logs=include_logs,
             serving_hid=str(order_run_id),
-            servingjson=False,
-            summary=False,
-            testresults=False,
-            timingresults=False
+            servingjson=include_servingjson,
+            summary=include_summary,
+            testresults=include_testresults,
+            timingresults=include_timingresults
         ).json()
         return api_response['servings'][0]
 
